//---------------------------------------------------------------------------
//    $Id: theta_timestepping.h 23709 2011-05-17 04:34:08Z bangerth $
//
//    Copyright (C) 2010 by the deal.II authors
//
//    This file is subject to QPL and may not be  distributed
//    without copyright and license information. Please refer
//    to the file deal.II/doc/license.html for the  text  and
//    further information on this license.
//
//---------------------------------------------------------------------------

/**
 * @file
 * @deprecated This file has moved to <tt>lac/algorithms</tt>
 */

#include <deal.II/algorithms/theta_timestepping.h>
